/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.adexchangebuyer.model;

import com.google.api.client.json.GenericJson;

/**
 * Configuration data for an Ad Exchange buyer account.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Ad Exchange Buyer API. For a detailed explanation
 * see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Account extends GenericJson {

  /**
   * Your bidder locations that have distinct URLs.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<BidderLocation> bidderLocation;

  static {
    // hack to force ProGuard to consider BidderLocation used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(BidderLocation.class);
  }

  /**
   * The nid parameter value used in cookie match requests. Please contact your technical account
   * manager if you need to change this.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String cookieMatchingNid;

  /**
   * The base URL used in cookie match requests.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String cookieMatchingUrl;

  /**
   * Account id.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer id;

  /**
   * Resource type.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The sum of all bidderLocation.maximumQps values cannot exceed this. Please contact your
   * technical account manager if you need to change this.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer maximumTotalQps;

  /**
   * Your bidder locations that have distinct URLs.
   * The value returned may be {@code null}.
   */
  public java.util.List<BidderLocation> getBidderLocation() {
    return bidderLocation;
  }

  /**
   * Your bidder locations that have distinct URLs.
   * The value set may be {@code null}.
   */
  public Account setBidderLocation(java.util.List<BidderLocation> bidderLocation) {
    this.bidderLocation = bidderLocation;
    return this;
  }

  /**
   * The nid parameter value used in cookie match requests. Please contact your technical account
   * manager if you need to change this.
   * The value returned may be {@code null}.
   */
  public String getCookieMatchingNid() {
    return cookieMatchingNid;
  }

  /**
   * The nid parameter value used in cookie match requests. Please contact your technical account
   * manager if you need to change this.
   * The value set may be {@code null}.
   */
  public Account setCookieMatchingNid(String cookieMatchingNid) {
    this.cookieMatchingNid = cookieMatchingNid;
    return this;
  }

  /**
   * The base URL used in cookie match requests.
   * The value returned may be {@code null}.
   */
  public String getCookieMatchingUrl() {
    return cookieMatchingUrl;
  }

  /**
   * The base URL used in cookie match requests.
   * The value set may be {@code null}.
   */
  public Account setCookieMatchingUrl(String cookieMatchingUrl) {
    this.cookieMatchingUrl = cookieMatchingUrl;
    return this;
  }

  /**
   * Account id.
   * The value returned may be {@code null}.
   */
  public Integer getId() {
    return id;
  }

  /**
   * Account id.
   * The value set may be {@code null}.
   */
  public Account setId(Integer id) {
    this.id = id;
    return this;
  }

  /**
   * Resource type.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Resource type.
   * The value set may be {@code null}.
   */
  public Account setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The sum of all bidderLocation.maximumQps values cannot exceed this. Please contact your
   * technical account manager if you need to change this.
   * The value returned may be {@code null}.
   */
  public Integer getMaximumTotalQps() {
    return maximumTotalQps;
  }

  /**
   * The sum of all bidderLocation.maximumQps values cannot exceed this. Please contact your
   * technical account manager if you need to change this.
   * The value set may be {@code null}.
   */
  public Account setMaximumTotalQps(Integer maximumTotalQps) {
    this.maximumTotalQps = maximumTotalQps;
    return this;
  }

  /**
   * Model definition for AccountBidderLocation.
   */
  public static final class BidderLocation extends GenericJson {

    /**
     * The maximum queries per second the Ad Exchange will send.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer maximumQps;

    /**
     * The geographical region the Ad Exchange should send requests from. Only used by some quota
     * systems, but always setting the value is recommended. Allowed values: - ASIA  - EUROPE  -
     * US_EAST  - US_WEST
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String region;

    /**
     * The URL to which the Ad Exchange will send bid requests.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String url;

    /**
     * The maximum queries per second the Ad Exchange will send.
     * The value returned may be {@code null}.
     */
    public Integer getMaximumQps() {
      return maximumQps;
    }

    /**
     * The maximum queries per second the Ad Exchange will send.
     * The value set may be {@code null}.
     */
    public BidderLocation setMaximumQps(Integer maximumQps) {
      this.maximumQps = maximumQps;
      return this;
    }

    /**
     * The geographical region the Ad Exchange should send requests from. Only used by some quota
     * systems, but always setting the value is recommended. Allowed values: - ASIA  - EUROPE  -
     * US_EAST  - US_WEST
     * The value returned may be {@code null}.
     */
    public String getRegion() {
      return region;
    }

    /**
     * The geographical region the Ad Exchange should send requests from. Only used by some quota
     * systems, but always setting the value is recommended. Allowed values: - ASIA  - EUROPE  -
     * US_EAST  - US_WEST
     * The value set may be {@code null}.
     */
    public BidderLocation setRegion(String region) {
      this.region = region;
      return this;
    }

    /**
     * The URL to which the Ad Exchange will send bid requests.
     * The value returned may be {@code null}.
     */
    public String getUrl() {
      return url;
    }

    /**
     * The URL to which the Ad Exchange will send bid requests.
     * The value set may be {@code null}.
     */
    public BidderLocation setUrl(String url) {
      this.url = url;
      return this;
    }

  }

}
