/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.adexchangebuyer.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * The configuration data for an Ad Exchange direct deal.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Ad Exchange Buyer API. For a detailed explanation
 * see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class DirectDeal extends GenericJson {

  /**
   * The account id of the buyer this deal is for.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer accountId;

  /**
   * The name of the advertiser this deal is for.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String advertiser;

  /**
   * The currency code that applies to the fixed_cpm value. If not set then assumed to be USD.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String currencyCode;

  /**
   * End time for when this deal stops being active. If not set then this deal is valid until
   * manually disabled by the publisher. In seconds since the epoch.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long endTime;

  /**
   * The fixed price for this direct deal. In cpm micros of currency according to currency_code. If
   * set, then this deal is eligible for the fixed price tier of buying (highest priority, pay
   * exactly the configured fixed price).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long fixedCpm;

  /**
   * Deal id.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long id;

  /**
   * Resource type.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The minimum price for this direct deal. In cpm micros of currency according to currency_code.
   * If set, then this deal is eligible for the private exchange tier of buying (below fixed price
   * priority, run as a second price auction).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long privateExchangeMinCpm;

  /**
   * The name of the publisher offering this direct deal.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String sellerNetwork;

  /**
   * Start time for when this deal becomes active. If not set then this deal is active immediately
   * upon creation. In seconds since the epoch.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long startTime;

  /**
   * The account id of the buyer this deal is for.
   * The value returned may be {@code null}.
   */
  public Integer getAccountId() {
    return accountId;
  }

  /**
   * The account id of the buyer this deal is for.
   * The value set may be {@code null}.
   */
  public DirectDeal setAccountId(Integer accountId) {
    this.accountId = accountId;
    return this;
  }

  /**
   * The name of the advertiser this deal is for.
   * The value returned may be {@code null}.
   */
  public String getAdvertiser() {
    return advertiser;
  }

  /**
   * The name of the advertiser this deal is for.
   * The value set may be {@code null}.
   */
  public DirectDeal setAdvertiser(String advertiser) {
    this.advertiser = advertiser;
    return this;
  }

  /**
   * The currency code that applies to the fixed_cpm value. If not set then assumed to be USD.
   * The value returned may be {@code null}.
   */
  public String getCurrencyCode() {
    return currencyCode;
  }

  /**
   * The currency code that applies to the fixed_cpm value. If not set then assumed to be USD.
   * The value set may be {@code null}.
   */
  public DirectDeal setCurrencyCode(String currencyCode) {
    this.currencyCode = currencyCode;
    return this;
  }

  /**
   * End time for when this deal stops being active. If not set then this deal is valid until
   * manually disabled by the publisher. In seconds since the epoch.
   * The value returned may be {@code null}.
   */
  public Long getEndTime() {
    return endTime;
  }

  /**
   * End time for when this deal stops being active. If not set then this deal is valid until
   * manually disabled by the publisher. In seconds since the epoch.
   * The value set may be {@code null}.
   */
  public DirectDeal setEndTime(Long endTime) {
    this.endTime = endTime;
    return this;
  }

  /**
   * The fixed price for this direct deal. In cpm micros of currency according to currency_code. If
   * set, then this deal is eligible for the fixed price tier of buying (highest priority, pay
   * exactly the configured fixed price).
   * The value returned may be {@code null}.
   */
  public Long getFixedCpm() {
    return fixedCpm;
  }

  /**
   * The fixed price for this direct deal. In cpm micros of currency according to currency_code. If
   * set, then this deal is eligible for the fixed price tier of buying (highest priority, pay
   * exactly the configured fixed price).
   * The value set may be {@code null}.
   */
  public DirectDeal setFixedCpm(Long fixedCpm) {
    this.fixedCpm = fixedCpm;
    return this;
  }

  /**
   * Deal id.
   * The value returned may be {@code null}.
   */
  public Long getId() {
    return id;
  }

  /**
   * Deal id.
   * The value set may be {@code null}.
   */
  public DirectDeal setId(Long id) {
    this.id = id;
    return this;
  }

  /**
   * Resource type.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Resource type.
   * The value set may be {@code null}.
   */
  public DirectDeal setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The minimum price for this direct deal. In cpm micros of currency according to currency_code.
   * If set, then this deal is eligible for the private exchange tier of buying (below fixed price
   * priority, run as a second price auction).
   * The value returned may be {@code null}.
   */
  public Long getPrivateExchangeMinCpm() {
    return privateExchangeMinCpm;
  }

  /**
   * The minimum price for this direct deal. In cpm micros of currency according to currency_code.
   * If set, then this deal is eligible for the private exchange tier of buying (below fixed price
   * priority, run as a second price auction).
   * The value set may be {@code null}.
   */
  public DirectDeal setPrivateExchangeMinCpm(Long privateExchangeMinCpm) {
    this.privateExchangeMinCpm = privateExchangeMinCpm;
    return this;
  }

  /**
   * The name of the publisher offering this direct deal.
   * The value returned may be {@code null}.
   */
  public String getSellerNetwork() {
    return sellerNetwork;
  }

  /**
   * The name of the publisher offering this direct deal.
   * The value set may be {@code null}.
   */
  public DirectDeal setSellerNetwork(String sellerNetwork) {
    this.sellerNetwork = sellerNetwork;
    return this;
  }

  /**
   * Start time for when this deal becomes active. If not set then this deal is active immediately
   * upon creation. In seconds since the epoch.
   * The value returned may be {@code null}.
   */
  public Long getStartTime() {
    return startTime;
  }

  /**
   * Start time for when this deal becomes active. If not set then this deal is active immediately
   * upon creation. In seconds since the epoch.
   * The value set may be {@code null}.
   */
  public DirectDeal setStartTime(Long startTime) {
    this.startTime = startTime;
    return this;
  }

}
